import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

import "../Common"
import "../Sheets"

Page {
    id: settings

    tools: settingsTools

    orientationLock: PageOrientation.LockPortrait

    function saveValues() {
        var saveConf={
            servername:serverName.text,
            username:userName.text,
            password:passWord.text,
            maxitems:chooseMaxItems.currentValue,
            usessl:sslCheck.checked,
            ignoresslerrors:ignoreSsl.checked,
            orderby:chooseOrderBy.currentValue,
            textformat:textFormatSelection.valueChoosen,
            themecolor:invertThemeSelection.choosenValue,
            showimgs:showImgByDefaultSelection.choosenValue
        };

        return saveConf;
    }

    Component.onCompleted: {
        configuration.getConfig();
        if (configuration.getSetting("display/privacypolicy", false) == false) {
            settingsPrivacySheet.policy = configuration.getSetting("display/privacypolicy", false) == "true" ? true : false;
            settingsPrivacySheet.open();
        }
        configuration.getStatistics();
    }
    Component.onDestruction: configuration.saveConfig(saveValues());

    // ------------- Header Start ----------------

        Header {
            id: settingsPageHeader
            text: qsTr("Settings")
        }

    // ------------- Header End ----------------



    TabGroup {
        id: tabgroup
        currentTab: tab1
        anchors { top: settingsPageHeader.bottom; topMargin: 5 }

        Page {
            id: tab1
            orientationLock: PageOrientation.LockPortrait

            Label {
                id: serverLabel
                anchors { top: parent.top; left: parent.left; topMargin: 10; leftMargin: 20 }
                text: qsTr("ownCloud Server")
                visible: true
                textFormat: Text.PlainText
            }

            TextField {
                id: serverName
                anchors { top: serverLabel.bottom; horizontalCenter: parent.horizontalCenter }
                height: 50
                width: (parent.width - 20)
                placeholderText: qsTr("e.g. cloud.example.com")
                inputMethodHints: Qt.ImhUrlCharactersOnly
                Connections {
                    target: configuration
                    onGotConfig: serverName.text = config["servername"]
                }
            }


            Label {
                id: userLabel
                anchors { top: serverName.bottom; left: parent.left; topMargin: 10; leftMargin: 20 }
                text: qsTr("User")
                visible: true
                textFormat: Text.PlainText
            }

            TextField {
                id: userName
                anchors { top: userLabel.bottom; horizontalCenter: parent.horizontalCenter }
                height: 50
                width: (parent.width - 20)
                placeholderText: qsTr("Enter user name")
                Connections {
                    target: configuration
                    onGotConfig: userName.text = config["username"]
                }
            }

            Label {
                id: passwordLabel
                anchors { top: userName.bottom; left: parent.left; topMargin: 10; leftMargin: 20 }
                text: qsTr("Password")
                visible: true
                textFormat: Text.PlainText
            }

            TextField {
                id: passWord;
                echoMode: TextInput.Password;
                anchors { top: passwordLabel.bottom; horizontalCenter: parent.horizontalCenter }
                height: 50
                width: (parent.width - 20)
                placeholderText: qsTr("Enter your password")
                Connections {
                    target: configuration
                    onGotConfig: passWord.text = config["password"]
                }
            }

            CheckBox {
                id: sslCheck
                text: qsTr("Use HTTPS (SSL) connection")
                checked: true
                anchors { top: passWord.bottom; left: parent.left; leftMargin: 20; topMargin: 20 }
                onClicked: sslCheck.checked == false ? disableSSLQuery.open() : ""
                Connections {
                    target: configuration
                    onGotConfig: sslCheck.checked = config["usessl"]
                }
            }

            CheckBox {
                id: ignoreSsl
                text: qsTr("Ignore SSL errors")
                checked: false
                enabled: sslCheck.checked
                anchors { top: sslCheck.bottom; left: parent.left; leftMargin: 20; topMargin: 20 }
                Connections {
                    target: configuration
                    onGotConfig: ignoreSsl.checked = config["ignoresslerrors"]
                }
            }

            Button{
                id: testConnectionButton
                anchors { horizontalCenter: parent.horizontalCenter; top: ignoreSsl.bottom; topMargin: 20 }
                text: qsTr("Test Connection")
                onClicked: {
                    configuration.saveConfig(saveValues())
                    generic.getVersion()
                    testConnectionIndicator.visible = true
                    testConnectionIndicator.running = true
                    testConnectionButton.enabled = false
                    testConnectionButton.text = qsTr("Testing Connection")
                }
                Connections {
                    target: generic
                    onGotVersion: { testConnectionButton.enabled = true; testConnectionButton.text = qsTr("Test Connection") }
                    onGotVersionError: { testConnectionButton.enabled = true; testConnectionButton.text = qsTr("Test Connection") }
                }
            }

            BusyIndicator {
                id: testConnectionIndicator
                platformStyle: BusyIndicatorStyle { size: "large" }
                visible: false
                running: false
                anchors { horizontalCenter: parent.horizontalCenter; top: testConnectionButton.bottom; topMargin: 20 }
                Connections {
                    target: generic
                    onGotVersion: { testConnectionIndicator.visible = false; testConnectionIndicator.running = false }
                    onGotVersionError: { testConnectionIndicator.visible = false; testConnectionIndicator.running = false }
                }
            }
        }

        Page {
            id: tab2
            orientationLock: PageOrientation.LockPortrait

            ListModel {
                id: maxItemModel
                ListElement { name: "50"; value: "50" }
                ListElement { name: "100"; value: "100" }
                ListElement { name: "200"; value: "200" }
                ListElement { name: "500"; value: "500" }
            }

            SelectionItem {
                id: chooseMaxItems
                title: qsTr("Number of items to keep")
                width: (parent.width - 40)
                anchors { top: parent.top; topMargin: 10; horizontalCenter: parent.horizontalCenter }
                model: maxItemModel
                initialValue: "100"
                Connections {
                    target: configuration
                    onGotConfig: chooseMaxItems.initialValue = config["maxitems"]
                }
            }

            ListModel {
                id: orderByModel
                ListElement { name: ""; value: "id" }
                ListElement { name: ""; value: "title" }
                ListElement { name: ""; value: "unreadCount" }
                Component.onCompleted: {
                    orderByModel.get(0).name = qsTr("Added (like on server)")
                    orderByModel.get(1).name = qsTr("Title")
                    orderByModel.get(2).name = qsTr("Unread count")
                }
            }

            SelectionItem {
                id: chooseOrderBy
                title: qsTr("Order feeds and folders by")
                width: parent.width - 40
                anchors { top: chooseMaxItems.bottom; topMargin: 10; horizontalCenter: parent.horizontalCenter }
                model: orderByModel
                initialValue: "id"
                Connections {
                    target: configuration
                    onGotConfig: chooseOrderBy.initialValue = config["orderby"]
                }
            }


            Label {
                id: textFormatLabel
                anchors { top: chooseOrderBy.bottom; topMargin: 10; left: parent.left; leftMargin: 20 }
                text: qsTr("Display post content format")
                textFormat: Text.PlainText
            }

            ButtonRow {
                id: textFormatSelection
                property string valueChoosen
                anchors { top: textFormatLabel.bottom; horizontalCenter: parent.horizontalCenter }
                Button {
                    id: rich;
                    text: qsTr("Full");
                    checked: textFormatSelection.valueChoosen == "rich";
                    onClicked: textFormatSelection.valueChoosen = "rich"
                }
                Button {
                    id: styled;
                    text: qsTr("Limited");
                    checked: textFormatSelection.valueChoosen == "styled";
                    onClicked: textFormatSelection.valueChoosen = "styled"
                }
                Connections {
                    target: configuration
                    onGotConfig: textFormatSelection.valueChoosen = config["textformat"]
                }
            }


            Label {
                id: invertThemeLabel
                anchors { top: textFormatSelection.bottom; topMargin: 15; left: parent.left; leftMargin: 20 }
                text: qsTr("Theme color")
            }

            ButtonRow {
                id: invertThemeSelection
                property string choosenValue
                anchors { top: invertThemeLabel.bottom; horizontalCenter: parent.horizontalCenter }
                Button {
                    id: white
                    text: qsTr("White")
                    checked: invertThemeSelection.choosenValue == "white"
                    onClicked: { invertThemeSelection.choosenValue = "white"; theme.inverted = false }
                }
                Button {
                    id: black
                    text: qsTr("Black")
                    checked: invertThemeSelection.choosenValue == "black"
                    onClicked: { invertThemeSelection.choosenValue = "black"; theme.inverted = true }
                }
                Connections {
                    target: configuration
                    onGotConfig: invertThemeSelection.choosenValue = config["themecolor"]
                }
            }


            Label {
                id: showImgByDefaultLabel
                anchors { top: invertThemeSelection.bottom; topMargin: 15; left: parent.left; leftMargin: 20 }
                text: qsTr("Show images by default")
                visible: textFormatSelection.valueChoosen === "rich"
            }

            ButtonRow {
                id: showImgByDefaultSelection
                property string choosenValue
                anchors { top: showImgByDefaultLabel.bottom; horizontalCenter: parent.horizontalCenter }
                visible: textFormatSelection.valueChoosen === "rich"
                Button {
                    id: hide
                    text: qsTr("Hide")
                    checked: showImgByDefaultSelection.choosenValue == "hide"
                    onClicked: { showImgByDefaultSelection.choosenValue = "hide" }
                }
                Button {
                    id: show
                    text: qsTr("Show")
                    checked: showImgByDefaultSelection.choosenValue == "show"
                    onClicked: { showImgByDefaultSelection.choosenValue = "show" }
                }
                Connections {
                    target: configuration
                    onGotConfig: showImgByDefaultSelection.choosenValue = config["showimgs"]
                }
            }
        }

        Page {
            id: tab3
            orientationLock: PageOrientation.LockPortrait


            Label {
                id: statsLabel
                text: qsTr("Database statistics")
                anchors { top: parent.top; left: parent.left; topMargin: 20; leftMargin: 20 }
                textFormat: Text.PlainText
            }

            Text {
                id: folderCount
                anchors { top: statsLabel.bottom; left: parent.left; topMargin: 10; leftMargin: 20 }
                font.pointSize: 17
                font.weight: Font.Light
                textFormat: Text.PlainText
                color: theme.inverted ? "white" : "black"
                Connections {
                    target: configuration
                    onGotStatistics: folderCount.text = qsTr("Folders: ") + statistics["folderCount"]
                }
            }

            Text {
                id: feedCount
                anchors { top: folderCount.bottom; left: parent.left; topMargin: 10; leftMargin: 20 }
                font.pointSize: 17
                font.weight: Font.Light
                textFormat: Text.PlainText
                color: theme.inverted ? "white" : "black"
                Connections {
                    target: configuration
                    onGotStatistics: feedCount.text = qsTr("Feeds: ") + statistics["feedCount"]
                }
            }

            Text {
                id: itemCount
                anchors { top: feedCount.bottom; left: parent.left; topMargin: 10; leftMargin: 20 }
                font.pointSize: 17
                font.weight: Font.Light
                textFormat: Text.PlainText
                color: theme.inverted ? "white" : "black"
                Connections {
                    target: configuration
                    onGotStatistics: itemCount.text = qsTr("Posts: ") + statistics["itemCount"]
                }
            }

            Text {
                id: unreadCount
                anchors { top: itemCount.bottom; left: parent.left; topMargin: 10; leftMargin: 20 }
                font.pointSize: 17
                font.weight: Font.Light
                textFormat: Text.PlainText
                color: theme.inverted ? "white" : "black"
                Connections {
                    target: configuration
                    onGotStatistics: unreadCount.text = qsTr("Unread: ") + statistics["unreadCount"]
                }
            }

            Text {
                id: lastFullUpdate
                anchors { top: unreadCount.bottom; left: parent.left; topMargin: 10; leftMargin: 20 }
                font.pointSize: 17
                font.weight: Font.Light
                textFormat: Text.StyledText
                color: theme.inverted ? "white" : "black"
                Connections {
                    target: configuration
                    onGotStatistics: lastFullUpdate.text = qsTr("Last full update:<br />") + statistics["lastFullUpdate"]
                }
            }


            Button {
                id: resetConfigButton
                anchors { horizontalCenter: parent.horizontalCenter; top: lastFullUpdate.bottom; topMargin: 40 }
                text: qsTr("Reset configuration")
                onClicked: resetConfigQuery.open()
                enabled: serverName.text != ""
            }

            Button {
                id: deleteDBButton
                anchors { horizontalCenter: parent.horizontalCenter; top: resetConfigButton.bottom; topMargin: 20 }
                text: qsTr("Delete database")
                onClicked: deleteDBQuery.open()
                Connections {
                    target: configuration
                    onGotStatistics: statistics["feedCount"] + statistics["folderCount"] + statistics["itemCount"] == 0 ? deleteDBButton.enabled = false : deleteDBButton.enabled = true
                }
            }

            Button {
                id: deleteCertsButton
                anchors { horizontalCenter: parent.horizontalCenter; top: deleteDBButton.bottom; topMargin: 20 }
                text: qsTr("Remove certificates")
                onClicked: deleteCertsQuery.open()
            }
        }
    }



// ----------------- Toolbar Start --------------------

    ToolBarLayout {
        id: settingsTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: { pageStack.pop(); }
        }
        ButtonRow {
            style: TabButtonStyle { }
            TabButton {
                iconSource: "image://theme/icon-m-weather-mostly-cloudy"
                tab: tab1
            }
            TabButton {
                iconSource: "image://theme/icon-m-toolbar-settings"
                tab: tab2
            }
            TabButton {
                iconSource: "image://theme/icon-m-toolbar-tools"
                tab: tab3
            }
        }
    }
// ----------------- Toolbar End --------------------



// ----------------- Dialogs Start --------------------

    QueryDialog {
        id: resetConfigQuery
        icon: "image://theme/icon-m-bootloader-warning"
        acceptButtonText: qsTr("Reset")
        rejectButtonText: qsTr("Cancel")
        message: qsTr("Do you really want reset your configuration?")
        titleText: qsTr("Reset configuration?")
        onAccepted: configuration.resetConfig()
    }


    QueryDialog {
        id: deleteDBQuery
        icon: "image://theme/icon-m-bootloader-warning"
        acceptButtonText: qsTr("Delete")
        rejectButtonText: qsTr("Cancel")
        message: qsTr("Do you really want delete your complete database?")
        titleText: qsTr("Delete database?")
        onAccepted: configuration.cleanDatabase()
    }

    QueryDialog {
        id: deleteCertsQuery
        icon: "image://theme/icon-m-bootloader-warning"
        acceptButtonText: qsTr("Remove")
        rejectButtonText: qsTr("Cancel")
        message: qsTr("Do you really want remove your trustet SSL certificates (only for this application)?")
        titleText: qsTr("Remove trusted certificates?")
        onAccepted: configuration.cleanCertificates()
    }

    QueryDialog {
        id: disableSSLQuery
        icon: "image://theme/icon-m-bootloader-warning"
        acceptButtonText: qsTr("Disable")
        rejectButtonText: qsTr("Enable")
        message: qsTr("It is not a good idea to disable HTTPS (SSL), because your username and password then will be sent unencrypted with every request.")
        titleText: qsTr("Disable HTTPS?")
        onAccepted: sslCheck.checked = "false"
        onRejected: sslCheck.checked = "true"
    }

// ----------------- Dialogs End --------------------


// ----------------- Sheet Start --------------------

    PrivacySheet {
        id: settingsPrivacySheet
    }

// ----------------- Sheet End --------------------
}
