import QtQuick 1.1
import com.nokia.meego 1.0

Sheet {
    property alias sslErrorMessage: errorString.text
    property alias model: certChain.model
    property string caller

//    acceptButtonText: qsTr("Add")
//    rejectButtonText: qsTr("Cancel")
    buttons: Item {
        id: buttonRow
        anchors.fill: parent
        SheetButton {
            id: rejectButton
            text: qsTr("Reject")
            anchors { left: parent.left; leftMargin: 10; verticalCenter: parent.verticalCenter }
            onClicked: {
                if (caller === "gen") {
                    generic.sslDecision(0);
                } else if (caller === "fol") {
                    folders.sslDecision(0);
                } else if (caller === "fee") {
                    feeds.sslDecision(0);
                } else if (caller === "ite") {
                    items.sslDecision(0);
                }
                close();
            }
        }
        SheetButton {
            id: button24h
            text: qsTr("Trust 24h")
            anchors { horizontalCenter: parent.horizontalCenter; verticalCenter: parent.verticalCenter }
            onClicked: {
                if (caller === "gen") {
                    generic.sslDecision(1);
                } else if (caller === "fol") {
                    folders.sslDecision(1);
                } else if (caller === "fee") {
                    feeds.sslDecision(1);
                } else if (caller === "ite") {
                    items.sslDecision(1);
                }
                close();
            }
        }
        SheetButton {
            id: trustButton
            text: qsTr("Trust")
            anchors { right: parent.right; rightMargin: 10; verticalCenter: parent.verticalCenter }
            onClicked: {
                if (caller === "gen") {
                    generic.sslDecision(2);
                } else if (caller === "fol") {
                    folders.sslDecision(2);
                } else if (caller === "fee") {
                    feeds.sslDecision(2);
                } else if (caller === "ite") {
                    items.sslDecision(2);
                }
                close();
            }
        }
    }



    content: Flickable {
            id: flickArea
            anchors { fill: parent; leftMargin: 10; topMargin: 10; rightMargin: 10 }
            flickableDirection: Flickable.VerticalFlick
            Label {
                id: sslDialogLabel
                text: qsTr("SSL Connection Error")
                anchors.top: parent.top
                platformStyle: LabelStyle { fontPixelSize: 30 }
                textFormat: Text.PlainText
            }
            Image {
               id: headerLine
               height: 2
               width: parent.width
               anchors { left: parent.left; right: parent.right; top: sslDialogLabel.bottom }
               source: "image://theme/meegotouch-separator" + (theme.inverted? "-inverted" : "") + "-background-horizontal"
               fillMode: Image.TileHorizontally
            }
            Text {
                id: errorString
                anchors { top: headerLine.bottom; topMargin: 10 }
                width: parent.width
                font.pointSize: 17
                font.weight: Font.Light
                wrapMode: Text.WordWrap
                textFormat: Text.PlainText
                color: theme.inverted ? "white" : "black"
            }
            Image {
               id: infoDevider
               height: 2
               width: parent.width
               anchors { left: parent.left; right: parent.right; top: errorString.bottom; topMargin: 10 }
               source: "image://theme/meegotouch-separator" + (theme.inverted? "-inverted" : "") + "-background-horizontal"
               fillMode: Image.TileHorizontally
            }
            Text {
                id: info
                anchors { top: infoDevider.bottom; topMargin: 10 }
                width: parent.width
                font.pointSize: 17
                font.weight: Font.Light
                wrapMode: Text.WordWrap
                textFormat: Text.PlainText
                text: qsTr("There are problems with the secure connection to your ownCloud Server. If you don't know what this means, then reject the displayed certificates. In that case you can not connect to the ownCloud server, but you will not send your login credentials through an unsecure connection. If you know what you are doing you can trust the certificates limitless or for 24 hours.")
            }
            ListView {
                id: certChain
                anchors { fill: parent; topMargin: 50 + errorString.height + 2 + sslDialogLabel.height + infoDevider.height + info.height }
                width: parent.width
                interactive: false
                delegate: Item {
                    id: certItem
                    height: 130
                    width: parent.width

                    BorderImage {
                            id: background
                            anchors { fill: parent; leftMargin: -flickArea.anchors.leftMargin; rightMargin: -flickArea.anchors.rightMargin }
                            visible: mouseArea.pressed
                            source: theme.inverted ? "image://theme/meegotouch-panel-inverted-background-pressed" : "image://theme/meegotouch-panel-background-pressed"
                        }

                    Column {
                        Label {
                            text: model.certType
                            wrapMode: Text.WordWrap
                        }
                        Text {
                            text: model.subjectCN
                            wrapMode: Text.WordWrap
                            font.pointSize: 17
                            font.weight: Font.Light
                            textFormat: Text.PlainText
                            color: theme.inverted ? "white" : "black"
                        }
                        Text {
                            text: model.subjectO
                            wrapMode: Text.WordWrap
                            font.pointSize: 17
                            font.weight: Font.Light
                            textFormat: Text.PlainText
                            color: theme.inverted ? "white" : "black"
                        }
                        Text {
                            text: model.effectiveDate + qsTr(" to ") + model.expiryDate
                            color: model.isValid ? "black" : "red"
                            font.pointSize: 17
                            font.weight: Font.Light
                            textFormat: Text.PlainText
                        }
                    }

                    Image {
                        source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                        anchors { right: parent.right; verticalCenter: parent.verticalCenter }
                    }

                    MouseArea {
                        id: mouseArea;
                        anchors.fill: parent
                        onClicked: {
                            certDetail.cn = model.subjectCN
                            certDetail.org = model.subjectO
                            certDetail.orgunit = model.subjectOU
                            certDetail.certType = model.certType
                            certDetail.location = model.subjectL + " - " + model.subjectST + " - " + model.subjectC
                            certDetail.dates = qsTr("Valid from ") + model.effectiveDate + qsTr(" to ") + model.expiryDate
                            certDetail.sha1 = model.digestSHA1
                            certDetail.md5 = model.digestMD5
                            certDetail.open()
                        }
                    }
                }
            }
    }
//    onAccepted: folders.createFolder(folderName.text);

    CertSheet {
        id: certDetail
    }
}

